@@ -85,7 +85,7 @@ class Course:
             for activity in lesson.active_activies:
                 tmp_activities.append({'type': activity.activity_type,
                                        'title': activity.title,
-                                       'file': activity.src,
+                                       'file': activity.activity_html_file_src if activity.activity_type in  ['reading','quiz'] and activity.get_src_ext() != 'pdf' else activity.src,
                                        'description': activity.description,
                                        'guid': activity.guid}
                                       )
@@ -97,10 +97,9 @@ class Course:
                                          'guid': lesson.guid,
                                          'description':  lesson.description,
                                          'folder': lesson.folder,
-                                         'activities': tmp_activities}
+                                         'activities': tmp_activities,
+                                         'archived-activities': tmp_archived,}
                                         )
-            if len(tmp_archived):
-                self.dict['lessons'].append({'archived-activities': tmp_archived})
             if len(self.archived_lessons):
                 self.dict['archived-lessons'] = []
                 for al in self.archived_lessons:
@@ -114,6 +113,7 @@ class Course:
         course_dict = dict()
         course_dict['active_lessons'] = []
         course_dict['longDesc'] = self.longDesc
+        course_dict['shortDesc'] = self.shortDesc
         course_dict['willLearn'] = self.willlearn
         course_dict['requirements'] = self.requirements
         course_dict['toc'] = self.toc
@@ -153,31 +153,33 @@ class Activity:
     def __init__(self, activity_type, title, src, guid, description, nbsrc):
         self.activity_type = activity_type
         self.title = title
-        self.nbsrc = nbsrc
+        self.guid = guid
+        self.nbsrc = nbsrc if nbsrc else ''
         self.description = description if description else ''
         if self.activity_type == 'video':
             self.src = video_url(src)
             self.toc_url = self.title.replace(" ", "%20")
+            self.activity_html_file_src =  self.title.replace("?","") + '.html'
         elif self.activity_type == 'coding-quiz':
             self.toc_url =  self.title.replace(" ", "%20")
             self.src = src
+            self.activity_html_file_src = self.title.replace("?","")  + '.html'
+        # reading, quiz
         else:
             self.src = src
-            if self.get_src_ext() == 'ipynb' and self.nbsrc:
-                self.nbsrc = os.path.join(self.nbsrc[3:], src)
-            if self.get_src_ext() == 'pdf':
-                self.toc_url =  self.title.replace(" ", "%20")
             if self.get_src_ext() == 'ipynb':
+                if self.nbsrc:
+                    self.nbsrc = os.path.join(self.nbsrc[3:], src)
                 self.toc_url =  self.title.replace(" ", "%20")
+                self.activity_html_file_src = self.title.replace("?","")  + '.html'
+            elif self.get_src_ext() == 'pdf':
+                self.toc_url =  self.title.replace(" ", "%20")
+                self.activity_html_file_src = self.title.replace("?","")  + '.html'
             else:
                 self.toc_url = src.split('.')[0].replace(" ", "%20")
-        if guid.find('/') == -1:
-            self.guid = guid
-            self.alias = ''
-        else:
-            self.guid = guid.split('/')[0]
-            self.alias = guid.split('/')[1]
-
+                self.activity_html_file_src = self.src.replace('.rst','.html').replace("?","") 
+        self.toc_url = normalize(self.toc_url)
+        
     def get_src_ext(self):
         if len(self.src.rsplit('.')) > 1:
             return self.src.rsplit('.')[1]
@@ -307,10 +309,13 @@ def video_url(src):
 
 
 class ActivityTypeValueError(Exception):
-
     def __init__(self, *args):
         super(ActivityTypeValueError, self).__init__(args[0])
         if args:
             self.message = args[0]
         else:
             self.message = None
+
+def normalize(string : str):
+    reserved_chars = ['?','>',':','"','/','\\','|','*']
+    return ''.join(char for char in string if char not in reserved_chars)
\ No newline at end of file
